@@ -450,7 +450,7 @@ class MetricSuite:
 
 class Metric(SquadObject):
     endpoint = '/api/metrics/'
-    attrs = ['url', 'id', 'name', 'short_name', 'measurement_list', 'result', 'is_outlier', 'test_run', 'suite', 'metadata']
+    attrs = ['url', 'id', 'name', 'short_name', 'measurement_list', 'result', 'unit', 'is_outlier', 'test_run', 'suite', 'metadata']
 
 
 class TestRunStatus(SquadObject):
@@ -471,13 +471,6 @@ class TestRun(SquadObject):
     attachments = None
     log = None
 
-    def __setattr__(self, attr, value):
-        if attr == 'environment' and type(value) is str and value.startswith('http'):
-            response = SquadApi.get(value)
-            objs = self.__fill__(Environment, [response.json()])
-            value = first(objs)
-        super(TestRun, self).__setattr__(attr, value)
-
     __tests__ = None
 
     def add_test(self, test):
@@ -556,7 +549,7 @@ class Test(SquadObject):
 
     endpoint = '/api/tests/'
     attrs = ['url', 'id', 'name', 'short_name', 'status', 'result', 'test_run', 'log', 'has_known_issues',
-             'suite', 'known_issues']
+             'suite', 'known_issues', 'build', 'environment']
 
 
 class Suite(SquadObject):
